==> kubernetes-model-1.0.49-sources.jar: annotations/io/fabric8/openshift/api/model/DoneableClusterPolicyBinding.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.model.Doneable;
import io.fabric8.kubernetes.api.builder.Function;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class DoneableClusterPolicyBinding extends ClusterPolicyBindingFluentImpl<DoneableClusterPolicyBinding> implements Doneable<ClusterPolicyBinding>, ClusterPolicyBindingFluent<DoneableClusterPolicyBinding>{


    private final ClusterPolicyBindingBuilder builder;    private final Function<ClusterPolicyBinding, ClusterPolicyBinding> function;
    public DoneableClusterPolicyBinding ( Function<ClusterPolicyBinding, ClusterPolicyBinding> function){
    this.builder=new ClusterPolicyBindingBuilder(this);this.function=function;
}
    public DoneableClusterPolicyBinding ( ClusterPolicyBinding item,  Function<ClusterPolicyBinding, ClusterPolicyBinding> function){
    this.builder=new ClusterPolicyBindingBuilder(this, item);this.function=function;
}
    public DoneableClusterPolicyBinding ( ClusterPolicyBinding item){
    this.builder=new ClusterPolicyBindingBuilder(this, item);this.function=new Function<ClusterPolicyBinding, ClusterPolicyBinding>() {
    public ClusterPolicyBinding apply(ClusterPolicyBinding item) {
        return item;
    }
}
;
}

    public ClusterPolicyBinding done(){
     return function.apply(builder.build());
}


}

==> kubernetes-model-1.0.50-sources.jar: annotations/io/fabric8/openshift/api/model/DoneableClusterPolicyBinding.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.model.HasMetadata;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.KubernetesResource;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.model.Doneable;
import io.fabric8.kubernetes.api.builder.Function;
import io.fabric8.kubernetes.api.builder.Fluent;

public class DoneableClusterPolicyBinding extends ClusterPolicyBindingFluentImpl<DoneableClusterPolicyBinding> implements Doneable<ClusterPolicyBinding>,ClusterPolicyBindingFluent<DoneableClusterPolicyBinding>{


    private final ClusterPolicyBindingBuilder builder;    private final Function<ClusterPolicyBinding, ClusterPolicyBinding> function;
    public DoneableClusterPolicyBinding ( Function<ClusterPolicyBinding, ClusterPolicyBinding> function){
    this.builder=new ClusterPolicyBindingBuilder(this);this.function=function;
}
    public DoneableClusterPolicyBinding ( ClusterPolicyBinding item,  Function<ClusterPolicyBinding, ClusterPolicyBinding> function){
    this.builder=new ClusterPolicyBindingBuilder(this);this.function=function;
}
    public DoneableClusterPolicyBinding ( ClusterPolicyBinding item){
    this.builder=new ClusterPolicyBindingBuilder(this, item);this.function=new Function<ClusterPolicyBinding, ClusterPolicyBinding>() {
    public ClusterPolicyBinding apply(ClusterPolicyBinding item) {
        return item;
    }
}
;
}

    public ClusterPolicyBinding done(){
     return function.apply(builder.build());
}


}
